summaryrefslogtreecommitdiff
path: root/netci.groovy
diff options
context:
space:
mode:
Diffstat (limited to 'netci.groovy')
-rwxr-xr-xnetci.groovy3
1 files changed, 2 insertions, 1 deletions
diff --git a/netci.groovy b/netci.groovy
index 15092ed1da..2c269e7d4a 100755
--- a/netci.groovy
+++ b/netci.groovy
@@ -1534,8 +1534,9 @@ def static calculateBuildCommands(def newJob, def scenario, def branch, def isPR
case 'x64':
case 'x86':
if (architecture == 'x86' && os == 'Ubuntu') {
// build only, not test yet
buildCommands += "./tests/scripts/x86_ci_script.sh --buildConfig=${lowerConfiguration}"
+ Utilities.addXUnitDotNETResults(newJob, '**/pal_tests.xml')
break;
}
@@ -1534,8 +1534,9 @@ def static calculateBuildCommands(def newJob, def scenario, def branch, def isPR
case 'x86':
if (architecture == 'x86' && os == 'Ubuntu') {
- // build only, not test yet
+ // build and PAL test
buildCommands += "./tests/scripts/x86_ci_script.sh --buildConfig=${lowerConfiguration}"